@@ -1,7 +1,9 @@
 package TableData::Object;
 
-our $DATE = '2019-09-15'; # DATE
-our $VERSION = '0.111'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-29'; # DATE
+our $DIST = 'TableData-Object'; # DIST
+our $VERSION = '0.112'; # VERSION
 
 use 5.010001;
 use strict;
@@ -52,7 +54,7 @@ TableData::Object - Manipulate data structure via table object
 
 =head1 VERSION
 
-This document describes version 0.111 of TableData::Object (from Perl distribution TableData-Object), released on 2019-09-15.
+This document describes version 0.112 of TableData::Object (from Perl distribution TableData-Object), released on 2020-05-29.
 
 =for Pod::Coverage ^$
 
@@ -103,7 +105,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
