@@ -1,7 +1,9 @@
 package TableData::Object::hash;
 
-our $DATE = '2019-09-15'; # DATE
-our $VERSION = '0.111'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-29'; # DATE
+our $DIST = 'TableData-Object'; # DIST
+our $VERSION = '0.112'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,10 +26,32 @@ sub row_count {
     scalar keys %{ $self->{data} };
 }
 
+sub row {
+    my ($self, $idx) = @_;
+    # XXX not very efficient
+    my $rows = $self->rows;
+    $rows->[$idx];
+}
+
+sub row_as_aos {
+    my ($self, $idx) = @_;
+    # XXX not very efficient
+    my $rows = $self->rows;
+    $rows->[$idx];
+}
+
+sub row_as_hos {
+    my ($self, $idx) = @_;
+    # XXX not very efficient
+    my $rows = $self->rows;
+    my $row = $rows->[$idx];
+    return undef unless $row;
+    {key => $row->[0], value => $row->[1]};
+}
+
 sub rows {
     my $self = shift;
-    my $data = $self->{data};
-    [sort keys %$data];
+    $self->rows_as_aoaos;
 }
 
 sub rows_as_aoaos {
@@ -142,7 +166,7 @@ TableData::Object::hash - Manipulate hash via table object
 
 =head1 VERSION
 
-This document describes version 0.111 of TableData::Object::hash (from Perl distribution TableData-Object), released on 2019-09-15.
+This document describes version 0.112 of TableData::Object::hash (from Perl distribution TableData-Object), released on 2020-05-29.
 
 =head1 SYNOPSIS
 
@@ -192,7 +216,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
